Welcome to the documentation for MolSystem
==========================================

Contents:

.. toctree::
   :maxdepth: 1
   :titlesonly:

   user/index
   developer/index
   authors
   history

--------
   
.. toctree::
   :maxdepth: 1
   :titlesonly:

   Main SEAMM documentation <https://molssi-seamm.github.io>

Documentation Versions
----------------------

.. raw:: html

   <iframe
   src="https://molssi-seamm.github.io/molsystem/dev/versions.html"
   title="Documentation Versions"  style="border:none;">
   </iframe>

